@@ -13,18 +13,16 @@ incRpca <- function (d, Q, x, n, ff = 1/n, k = ncol(Q), center)
     if (length(na) > 0)
     		{ if (length(na) == length(x))
     			stop("x contains only NAs")
-    			 A <- Q * diag(sqrt(d))
+    			 A <- Q %*% diag(sqrt(d))
  		if (nrow(Q) - length(na) >= q)
-	 		{ x[na] <- A[na,, drop = FALSE] %*% 
- 				lsfit(A[-na,, drop = FALSE], x[-na], 
- 					intercept = FALSE)$coefficients
+	 		{ ginvAx.nona <- suppressWarnings(lsfit(A[-na,, drop = FALSE], x[-na], intercept = FALSE)$coefficients)
+	 			x[na] <- A[na,, drop = FALSE] %*% ginvAx.nona
  			} else {
  			svdA <- svd(A)
  			pos <- svdA$d > sqrt(.Machine$double.eps)
  				if (!any(pos))
 	 				{
-	 				Ainv <- tcrossprod(svdA$v[, pos, drop = FALSE] %*% 
-	 					diag(1/svdA$d[pos]), svdA$u[, pos, drop = FALSE])  
+	 				Ainv <- tcrossprod(svdA$v[, pos, drop = FALSE] %*% diag(1/svdA$d[pos]), svdA$u[, pos, drop = FALSE])  
 	 				x[na] <- A[na,, drop = FALSE] %*% Ainv %*% x[-na]
 	 				} else x[na] <- 0
  				}	
